# -*- coding: utf-8 -*-

#
# Full text search configuration - we must define that before the imports,
# because those are used by the imports
#

# Name of the PostgreSQL Text Search Configuration
TS_CONFIG_NAME = "simple_english"

# Name of the stopwards file, must be plain ASCII
STOPWORDS_FILE = "english"

# Global charset to use
CHARSET = "utf-8"

from sesql.orm.django import DjangoOrmAdapter
from sesql.fields import *
from sesql.sources import *
from django.db.models import Q
from pizza import models

#
# Select the ORM to use
#
orm = DjangoOrmAdapter()

#
# General condition to skip indexing content
#

SKIP_CONDITION = None

#
# Fields and tables configuration
#

# Configuration of SeSQL search fields
FIELDS = (ClassField("classname"),
          IntField("id"),

          StrField("name"),
          StrField("shop"),
          IntField('persons'),
          IntField('weight'),
          IntField('calories'),
          IntField('price'),
          IntField('crust'),
          IntArrayField('toppings', SubField('toppings', 'id')),
          IntArrayField('qualities'),
          IntArrayField('opendays', SubField('shop', 'computed_opendays()')),

          DateTimeField('indexed_at', sql_default = 'NOW()'),
          )

# Name of the global lookup table that should contain no real data
MASTER_TABLE_NAME = "sesql_index"

# Type map, associating Django classes to SeSQL tables
TYPE_MAP = ((models.Pizza, "sesql_pizzas"),
            # So they'll be tracked by SeSQL dep-tracking engine
            (models.Topping, None, False),
            (models.Shop, None, False),            
            )

# Additional indexes to create
CROSS_INDEXES = (("classname", "indexed_at"),
                 )

#
# Cleanup configuration
#

from htmlentitydefs import name2codepoint
from xml.sax import saxutils
from django.utils.html import strip_tags

html_entities = dict([('&%s;' % k, unichr(v).encode(CHARSET)) for k,v in name2codepoint.items() ])
ADDITIONAL_CLEANUP_FUNCTION = lambda value: strip_tags(saxutils.unescape(value, html_entities))

#
# Query configuration
#

# Default sort order for queries 
DEFAULT_ORDER = ("-indexed_at",)

# Default LIMIT in short queries
DEFAULT_LIMIT = 50

# First we ask for the SMART_QUERY_INITIAL first sorted items
SMART_QUERY_INITIAL = 2500
# Then, if we have at least SMART_QUERY_THRESOLD of our limit, we go on
SMART_QUERY_THRESOLD = 0.35
# If we have a second query, we do * (wanted/result) * SMART_QUERY_RATIO 
SMART_QUERY_RATIO = 3.0


#
# Long query cache configuration
#

# Maximal number of queries to store in the long query cache
QUERY_CACHE_MAX_SIZE = 10000
# Life time of a query in the query cache
QUERY_CACHE_EXPIRY = 24 * 3600

#
# Daemon configuration
#

DAEMON_DEFAULT_CHUNK=100
DAEMON_DEFAULT_DELAY=30
DAEMON_DEFAULT_PID='/var/run/sesql/update.pid'


# set sesql in async mode
ASYNCHRONOUS_INDEXING = False
